@@ -33,7 +33,7 @@ class NxPyDocs():
                             # 'show interface transceiver',
                             'show inventory',
                             # 'show ip arp vrf all',
-                            # 'show ip interface brief',
+                            'show ip interface brief',
                             # 'show ip ospf',
                             # 'show ip ospf interface',
                             # 'show ip ospf interface vrf all',
